@@ -22,15 +22,13 @@
 
 #include "fleetdlg.h"
 
-#include <QHeaderView>
-#include <QTableWidget>
+#include <KLocalizedString>
 
-#include <kcomponentdata.h>
-#include <kglobal.h>
-#include <kpushbutton.h>
-#include <KStandardGuiItem>
-#include <kguiitem.h>
-#include <klocale.h>
+#include <QDialogButtonBox>
+#include <QHeaderView>
+#include <QPushButton>
+#include <QTableWidget>
+#include <QVBoxLayout>
 
 #include "planet.h"
 #include "../players/player.h"
@@ -40,18 +38,26 @@ FleetDlg::FleetDlg( QWidget *parent,
                     const AttackFleetList &fleets,
                     const AttackFleetList &newFleets,
                     const AttackFleetList &standingOrders)
-    : KDialog(parent), m_newFleetList(newFleets), m_standingOrders(standingOrders), m_fleetList(fleets)
+    : QDialog(parent), m_newFleetList(newFleets), m_standingOrders(standingOrders), m_fleetList(fleets)
 {
     setObjectName( QLatin1String( "FleetDlg" ) );
     setModal( true );
-    setCaption( i18n("Fleet Overview") );
-    setButtons( KDialog::Ok );
+    setWindowTitle( i18n("Fleet Overview") );
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &FleetDlg::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &FleetDlg::reject);
 
     setupTable();
     update();
-
-    setMainWidget( m_fleetTable );
-    connect( this, SIGNAL(okClicked()), this, SLOT(accept()) );
+    mainLayout->addWidget(m_fleetTable);
+    mainLayout->addWidget(buttonBox);
 }
 
 
@@ -124,7 +130,7 @@ FleetDlg::setupTable()
 void
 FleetDlg::update()
 {
-    AttackFleetList fleets = m_standingOrders + m_newFleetList + m_fleetList;
+    const AttackFleetList fleets = m_standingOrders + m_newFleetList + m_fleetList;
     const int standingOrders = m_standingOrders.count();
     const int newFleets = standingOrders + m_newFleetList.count();
 
@@ -133,7 +139,7 @@ FleetDlg::update()
     int row = 0;
     QTableWidgetItem *item;
 
-    foreach (AttackFleet *curFleet, fleets) {
+    for (AttackFleet *curFleet : fleets) {
         item = new QTableWidgetItem();
         if( row < newFleets) {
           item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable);
@@ -174,7 +180,7 @@ FleetDlg::update()
         // number comparison. But as all values have the same amount of
         // characters/digits, sorting by string actually works.
 
-        item = new QTableWidgetItem(QString("%1").arg(KGlobal::locale()->formatNumber(curFleet->source->killPercentage(), 3)));
+        item = new QTableWidgetItem(QStringLiteral("%1").arg(curFleet->source->killPercentage(), 3, 'f', 3));
         item->setTextAlignment(Qt::AlignRight | Qt::AlignVCenter);
         item->setFlags(Qt::ItemIsEnabled);
         m_fleetTable->setItem(row, 5, item);
