@@ -37,23 +37,24 @@
 #include "../players/spectatorplayer.h"
 #include "../players/spectatorplayer_gui.h"
 #include "../game.h"
-#include <kconfig.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpushbutton.h>
-#include <KStandardGuiItem>
-#include <kglobal.h>
 
-#include <KLineEdit>
-#include <KComboBox>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
+
+#include <QComboBox>
 #include <QHeaderView>
 #include <QItemDelegate>
+#include <QLineEdit>
 #include <QList>
-#include <QDebug>
 #include <QLinkedList>
-#include <QPair>
 #include <QMenu>
+#include <QPair>
+#include <QPushButton>
 #include <QSignalMapper>
+#include <QDialogButtonBox>
+#include <QVBoxLayout>
 
 /*************************************************************************
  New Game Dialog Members
@@ -92,18 +93,18 @@ public:
         }
     }
 
-    int rowCount(const QModelIndex &index = QModelIndex()) const
+    int rowCount(const QModelIndex &index = QModelIndex()) const override
     {
         Q_UNUSED(index);
         return m_players.count();
     }
 
-    int columnCount(const QModelIndex&) const
+    int columnCount(const QModelIndex&) const override
     {
         return 2;
     }
 
-    QVariant data(const QModelIndex &index, int role) const
+    QVariant data(const QModelIndex &index, int role) const override
     {
         if (index.isValid())
         {
@@ -129,7 +130,7 @@ public:
         return QVariant();
     }
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const
+    QVariant headerData(int section, Qt::Orientation orientation, int role) const override
     {
         if (orientation == Qt::Horizontal && role == Qt::DisplayRole)
         {
@@ -139,7 +140,7 @@ public:
         return QVariant();
     }
 
-    bool setData(const QModelIndex &index, const QVariant &value, int)
+    bool setData(const QModelIndex &index, const QVariant &value, int) override
     {
         bool result = false;
         if (index.isValid())
@@ -160,7 +161,7 @@ public:
             {
                 // The player controller changed.
                 QString playerGuiName = value.toString();
-                foreach (PlayerGui *playerGui, m_selectablePlayer)
+                for (PlayerGui *playerGui : qAsConst(m_selectablePlayer))
                 {
                     if (playerGui->guiName() == playerGuiName) {
                         Player *newPlayer = getNewPlayerByGui(playerGui, player->name(), player->color());
@@ -215,7 +216,7 @@ public:
         return player;
     }
 
-    Qt::ItemFlags flags(const QModelIndex &) const
+    Qt::ItemFlags flags(const QModelIndex &) const override
     {
         return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsEditable;
     }
@@ -277,38 +278,38 @@ public:
     {
     }
 
-    QWidget * createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const
+    QWidget * createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const override
     {
         if (index.column() == 0)
-            return new KLineEdit(parent);
+            return new QLineEdit(parent);
         else
-            return new KComboBox(parent);
+            return new QComboBox(parent);
     }
 
-    void setEditorData(QWidget *editor, const QModelIndex &index) const
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override
     {
         if (index.column() != 0) {
-            KComboBox *cbox = static_cast<KComboBox*>(editor);
+            QComboBox *cbox = static_cast<QComboBox*>(editor);
 
-            foreach (PlayerGui* playerGui, m_selectablePlayer) {
+            for (PlayerGui* playerGui : qAsConst(m_selectablePlayer)) {
                 cbox->addItem(playerGui->guiName());
             }
 
             cbox->setCurrentIndex( cbox->findText(index.data( Qt::DisplayRole).toString()) );
         } else {
-            KLineEdit *lineEdit = static_cast<KLineEdit*>(editor);
+            QLineEdit *lineEdit = static_cast<QLineEdit*>(editor);
             lineEdit->setText(index.data(Qt::DisplayRole).toString());
         }
     }
 
-    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override
     {
         if (index.column() != 0) {
-            KComboBox *cbox = static_cast<KComboBox*>(editor);
+            QComboBox *cbox = static_cast<QComboBox*>(editor);
 
             model->setData(index, cbox->currentText(), Qt::EditRole);
         } else {
-            KLineEdit *lineEdit = static_cast<KLineEdit*>(editor);
+            QLineEdit *lineEdit = static_cast<QLineEdit*>(editor);
 
             model->setData(index, lineEdit->text(), Qt::EditRole);
         }
@@ -319,14 +320,20 @@ private:
 };
 
 NewGameDlg::NewGameDlg( QWidget *parent, Game *game)
-    : KDialog( parent),
+    : QDialog( parent),
       m_game(game)
 {
     m_neutral = m_game->neutral();
-    setCaption(i18n("Start New Game"));
-    setButtons(KDialog::Ok|KDialog::Cancel);
-    setDefaultButton(KDialog::NoDefault);
-    showButtonSeparator(true);
+    setWindowTitle(i18n("Start New Game"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &NewGameDlg::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &NewGameDlg::reject);
 
     m_selectablePlayer.push_back(new LocalPlayerGui());
     m_selectablePlayer.push_back(new SpectatorPlayerGui());
@@ -345,36 +352,37 @@ NewGameDlg::NewGameDlg( QWidget *parent, Game *game)
         PlayerGui *selectablePlayer = m_selectablePlayer[i];
         QAction *action = m_playerTypeChooser->addAction(selectablePlayer->guiName());
         menuMapper->setMapping(action, i);
-        connect(action, SIGNAL(triggered(bool)), menuMapper, SLOT(map()));
+        connect(action, &QAction::triggered, menuMapper, static_cast<void (QSignalMapper::*)()>(&QSignalMapper::map));
     }
-    connect(menuMapper, SIGNAL(mapped(int)), this, SLOT(slotAddPlayer(int)));
+    connect(menuMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped), this, &NewGameDlg::slotAddPlayer);
 
     m_w = new NewGameDlgUI(this);
     m_w->map->setMap(m_game->map());
 
-    connect(m_w->map, SIGNAL(sectorSelected(Coordinate)),
-            this, SLOT(slotUpdateSelection(Coordinate)));
+    connect(m_w->map, &MiniMapView::sectorSelected, this, &NewGameDlg::slotUpdateSelection);
 
     playersListModel *model = new playersListModel(this, m_game, m_selectablePlayer);
 
     m_w->playerList->setModel(model);
     m_w->playerList->setItemDelegate(new playersListDelegate(this, m_selectablePlayer));
-    m_w->playerList->header()->setResizeMode(QHeaderView::ResizeToContents);
+    m_w->playerList->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     m_w->addPlayerButton->setMenu(m_playerTypeChooser);
 
-    connect(m_w->neutralPlanetsSB, SIGNAL(valueChanged(int)), this, SLOT(slotUpdateNeutrals(int)));
-    connect(m_w->widthSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewMap()));
-    connect(m_w->heightSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewMap()));
-    connect(m_w->randomizeMap, SIGNAL(clicked()), this, SLOT(slotNewMap()));
-    connect(m_w->removePlayerButton, SIGNAL(clicked()), this, SLOT(slotRemovePlayer()));
+    connect(m_w->neutralPlanetsSB, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewGameDlg::slotUpdateNeutrals);
+    connect(m_w->widthSB, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewGameDlg::slotNewMap);
+    connect(m_w->heightSB, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewGameDlg::slotNewMap);
+    connect(m_w->randomizeMap, &QPushButton::clicked, this, &NewGameDlg::slotNewMap);
+    connect(m_w->removePlayerButton, &QPushButton::clicked, this, &NewGameDlg::slotRemovePlayer);
 
-    connect(m_w->OwnerCB, SIGNAL(currentIndexChanged(int)), this, SLOT(slotNewOwner(int)));
-    connect(m_w->KillPercentageSB, SIGNAL(valueChanged(double)), this, SLOT(slotNewKillPercentage(double)));
-    connect(m_w->ProductionSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewProduction(int)));
+    connect(m_w->OwnerCB, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewGameDlg::slotNewOwner);
+    connect(m_w->KillPercentageSB, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &NewGameDlg::slotNewKillPercentage);
+    connect(m_w->ProductionSB, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewGameDlg::slotNewProduction);
 
     init();
 
-    setMainWidget(m_w);
+    mainLayout->addWidget(m_w);
+    mainLayout->addWidget(buttonBox);
+    okButton->setDefault(true);
     slotNewMap();
 
     updateButtonOk();
@@ -391,7 +399,7 @@ NewGameDlg::updateOwnerCB()
     m_w->OwnerCB->clear();
 
     m_w->OwnerCB->addItem(i18n("vacant"));
-    foreach(Player *player, m_game->players())
+    for (Player* player : m_game->players())
         m_w->OwnerCB->addItem(player->name());
     m_w->OwnerCB->addItem(i18n("neutral"));
 }
@@ -400,7 +408,7 @@ NewGameDlg::updateOwnerCB()
 void
 NewGameDlg::init()
 {
-    KConfigGroup config = KGlobal::config()->group("Game");
+    KConfigGroup config = KSharedConfig::openConfig()->group("Game");
 
     int nrOfPlayers = config.readEntry("NrOfPlayers",0);
     if (nrOfPlayers < 2)
@@ -495,7 +503,7 @@ NewGameDlg::slotUpdateSelection(const Coordinate &coord)
     m_w->KillPercentageSB->setEnabled(hasPlanet);
     m_w->ProductionSB->setEnabled(hasPlanet);
 
-    disconnect(m_w->OwnerCB, SIGNAL(currentIndexChanged(int)), this, SLOT(slotNewOwner(int)));
+    disconnect(m_w->OwnerCB, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewGameDlg::slotNewOwner);
 
     if (hasPlanet) {
         Planet *planet = sector->planet();
@@ -514,7 +522,7 @@ NewGameDlg::slotUpdateSelection(const Coordinate &coord)
         m_w->OwnerCB->setCurrentIndex(0);
     }
 
-    connect(m_w->OwnerCB, SIGNAL(currentIndexChanged(int)), this, SLOT(slotNewOwner(int)));
+    connect(m_w->OwnerCB, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewGameDlg::slotNewOwner);
 }
 
 
@@ -564,7 +572,7 @@ NewGameDlg::slotNewProduction(int value)
 void
 NewGameDlg::save()
 {
-    KConfigGroup config = KGlobal::config()->group("Game");
+    KConfigGroup config = KSharedConfig::openConfig()->group("Game");
     
     config.writeEntry("NrOfPlanets", m_w->neutralPlanetsSB->value());
     config.writeEntry("SizeWidth", m_w->widthSB->value());
@@ -610,9 +618,9 @@ NewGameDlg::slotNewMap()
     // make sure we have space for neutrals
     int maxneutrals = m_w->heightSB->value()*m_w->widthSB->value() - m_game->players().count();
     if(m_w->neutralPlanetsSB->value() > maxneutrals) {
-        disconnect(m_w->neutralPlanetsSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewMap()));
+        disconnect(m_w->neutralPlanetsSB, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewGameDlg::slotNewMap);
         m_w->neutralPlanetsSB->setValue(maxneutrals);
-        connect(m_w->neutralPlanetsSB, SIGNAL(valueChanged(int)), this, SLOT(slotNewMap()));
+        connect(m_w->neutralPlanetsSB, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &NewGameDlg::slotNewMap);
     }
 
     // make the planets
@@ -648,7 +656,7 @@ NewGameDlg::updateButtonOk()
     int nonSpectatorCount = 0;
     bool isSaneConfiguration = true;
 
-    foreach (Player *player, m_game->players()) {
+    for (Player *player : m_game->players()) {
         if (player->isSpectator()) {
 
             // Spectator player controllers can be completely ignored here as
@@ -662,7 +670,7 @@ NewGameDlg::updateButtonOk()
 
         bool foundPlanet = false;
 
-        foreach (Planet *planet, m_game->planets()) {
+        for (Planet *planet : m_game->planets()) {
             if (planet->player() == player) {
                 foundPlanet = true;
                 break;
@@ -675,7 +683,7 @@ NewGameDlg::updateButtonOk()
         }
     }
 
-    enableButtonOk(
+    okButton->setEnabled(
         (nonSpectatorCount >= 2) &&
         isSaneConfiguration
     );
