@@ -32,9 +32,9 @@
 #include <QPixmap>
 #include <QKeyEvent>
 #include <QIntValidator>
-#include <KDebug>
+#include <QDebug>
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include "players/player.h"
 #include "players/localplayer.h"
@@ -160,14 +160,10 @@ GameView::GameView(QWidget *parent, Game *game, QDockWidget *messagesDock, QDock
     //**********************************************************************
     // Set up signal/slot connections
     //**********************************************************************
-    connect( m_mapScene,      SIGNAL( planetSelected(Planet *) ),
-             this,            SLOT(planetSelected(Planet *)) );
-    connect( m_shipCountEdit, SIGNAL(returnPressed()),
-             this,            SLOT(newShipCount()) );
-    connect( m_standingOrder, SIGNAL(clicked()),
-             this,            SLOT(standingOrdersClicked()) );
-    connect( m_endTurnBtn,    SIGNAL( clicked() ),
-             this,            SLOT( nextPlayer() ) );
+    connect(m_mapScene, &MapScene::planetSelected, this, &GameView::planetSelected);
+    connect(m_shipCountEdit, &QLineEdit::returnPressed, this, &GameView::newShipCount);
+    connect(m_standingOrder, &QCheckBox::clicked, this, &GameView::standingOrdersClicked);
+    connect(m_endTurnBtn, &QPushButton::clicked, this, &GameView::nextPlayer);
 
     changeGameView();
 }
@@ -235,7 +231,7 @@ GameView::keyPressEvent( QKeyEvent *e )
 
     planetName += e->text().toUpper();
     
-    foreach (Planet *p, m_game->planets()) {
+    for (Planet *p : m_game->planets()) {
         if( p->name() == planetName ) {
             if ( m_showInformations ) {
                 m_mapScene->selectPlanet(p);
@@ -489,7 +485,7 @@ GameView::startNewGame()
 
     delete newGame;
 
-    foreach (Player *player, m_game->players()) {
+    for (Player *player : m_game->players()) {
         if (player->isSpectator()) {
 
             // All planets a spectator player has assigned are turned into
@@ -501,10 +497,10 @@ GameView::startNewGame()
 
         LocalPlayer *local = qobject_cast<LocalPlayer*>(player);
         if (local)
-            connect(local, SIGNAL(canPlay()), this, SLOT(turnPreparation()));
+            connect(local, &LocalPlayer::canPlay, this, &GameView::turnPreparation);
     }
 
-    connect(m_game, SIGNAL(finished()), this, SLOT(gameOver()));
+    connect(m_game, &Game::finished, this, &GameView::gameOver);
     m_game->start();
 
     // Fix all the widgets to run a new game.
@@ -552,7 +548,7 @@ void
 GameView::gameOver()
 {
     if (m_initCompleted) {
-        kDebug() << "Game over";
+        //qDebug() << "Game over";
 
         /**
          * @todo This is an attempt to remove duplicate information from screen.
@@ -601,7 +597,7 @@ GameView::cleanupGame()
 void
 GameView::planetSelected( Planet *planet )
 {
-    kDebug() << "planetSelected with " << m_guiState;
+    //qDebug() << "planetSelected with " << m_guiState;
     switch( m_guiState ) {
         case SOURCE_PLANET:
             if( planet->player() == m_game->currentPlayer() ) {
@@ -670,7 +666,7 @@ GameView::changeGameView()
 {
     bool isRunning = m_game->isRunning();
 
-    kDebug() << "Calling GameView::changeGameView" << isRunning;
+    //qDebug() << "Calling GameView::changeGameView" << isRunning;
 
     m_messagesDock->setVisible(isRunning);
 
@@ -736,8 +732,8 @@ GameView::showFleets()
     FleetDlg  *fleetDlg = new FleetDlg( this, current->attackList(),
                                         current->newAttacks(), current->standingOrders());
     if (fleetDlg->exec()) {
-        AttackFleetList *deleteAttacks = fleetDlg->uncheckedFleets();
-        foreach(AttackFleet *curFleet, *deleteAttacks) {
+        const AttackFleetList *deleteAttacks = fleetDlg->uncheckedFleets();
+        for (AttackFleet *curFleet : *deleteAttacks) {
             current->cancelNewAttack(curFleet);
         }
         delete deleteAttacks;
