@@ -22,9 +22,9 @@
 #ifndef KONQUEST_IMAGES_H
 #define KONQUEST_IMAGES_H
 
-#include <kstandarddirs.h>
+#include <QStandardPaths>
 
-#define IMAGE_SPLASH    KStandardDirs::locate("appdata", "pics/konquest-splash.png")
-#define IMAGES_SVG      KStandardDirs::locate("appdata", "pics/default_theme.svgz")
+#define IMAGE_SPLASH    QStandardPaths::locate(QStandardPaths::DataLocation, "pics/konquest-splash.png")
+#define IMAGES_SVG      QStandardPaths::locate(QStandardPaths::DataLocation, "pics/default_theme.svgz")
 
 #endif // KONQUEST_IMAGES_H
