@@ -26,7 +26,7 @@ class AiDefaultWeakGui : public PlayerGui
 {
 public:
     explicit AiDefaultWeakGui();
-    virtual Player* createInstance(Game *game, const QString &newName, const QColor &color) const;
+    Player* createInstance(Game *game, const QString &newName, const QColor &color) const override;
 };
 
 #endif // AI_DEFAULT_WEAK_GUI_H
