@@ -26,7 +26,7 @@ class SpectatorPlayerGui : public PlayerGui
 {
 public:
     explicit SpectatorPlayerGui();
-    virtual Player* createInstance(Game *game, const QString &newName, const QColor &color) const;
+    Player* createInstance(Game *game, const QString &newName, const QColor &color) const override;
 };
 
 #endif // SPECTATOR_PLAYER_GUI_H
